@@ -38,6 +38,10 @@
 #include <emscripten.h>
 #endif
 
+#ifdef __CYGWIN__
+#include <windows.h>
+#endif
+
 // Initialization code for SDL
 
 #include "SDL_assert_c.h"
@@ -555,6 +559,11 @@ quit_and_error:
 
 bool SDL_Init(SDL_InitFlags flags)
 {
+#ifdef __CYGWIN__
+    SetEnvironmentVariableA("ProgramData", getenv("ProgramData"));
+    SetEnvironmentVariableA("ALLUSERSPROFILE", getenv("ALLUSERSPROFILE"));
+    SetEnvironmentVariableA("LOCALAPPDATA", getenv("LOCALAPPDATA"));
+#endif
     return SDL_InitSubSystem(flags);
 }
 
