@@ -344,9 +344,9 @@ static void X11_GL_InitExtensions(SDL_VideoDevice *_this)
     const int screen = DefaultScreen(display);
     XVisualInfo *vinfo = NULL;
     Window w = 0;
-    GLXContext prev_ctx = 0;
+    GLXContext prev_ctx = NULL;
     GLXDrawable prev_drawable = 0;
-    GLXContext context = 0;
+    GLXContext context = NULL;
     const char *(*glXQueryExtensionsStringFunc)(Display *, int);
     const char *extensions;
 
@@ -468,6 +468,13 @@ static void X11_GL_InitExtensions(SDL_VideoDevice *_this)
         _this->gl_data->HAS_GLX_ARB_create_context_no_error = true;
     }
 
+    // Check for GLX_ARB_framebuffer_sRGB
+    if (HasExtension("GLX_ARB_framebuffer_sRGB", extensions)) {
+        _this->gl_data->HAS_GLX_ARB_framebuffer_sRGB = true;
+    } else if (HasExtension("GLX_EXT_framebuffer_sRGB", extensions)) {   // same thing.
+        _this->gl_data->HAS_GLX_ARB_framebuffer_sRGB = true;
+    }
+
     if (context) {
         _this->gl_data->glXMakeCurrent(display, None, NULL);
         _this->gl_data->glXDestroyContext(display, context);
@@ -578,9 +585,9 @@ static int X11_GL_GetAttributes(SDL_VideoDevice *_this, Display *display, int sc
         attribs[i++] = GLX_RGBA_FLOAT_TYPE_ARB;
     }
 
-    if (_this->gl_config.framebuffer_srgb_capable) {
+    if ((_this->gl_config.framebuffer_srgb_capable >= 0) && _this->gl_data->HAS_GLX_ARB_framebuffer_sRGB) {
         attribs[i++] = GLX_FRAMEBUFFER_SRGB_CAPABLE_ARB;
-        attribs[i++] = True; // always needed, for_FBConfig or not!
+        attribs[i++] = _this->gl_config.framebuffer_srgb_capable ? True : False; // always needed, for_FBConfig or not!
     }
 
     if (_this->gl_config.accelerated >= 0 &&
@@ -612,9 +619,9 @@ static int X11_GL_GetAttributes(SDL_VideoDevice *_this, Display *display, int sc
 }
 
 //get the first transparent Visual
-static XVisualInfo* X11_GL_GetTransparentVisualInfo(Display *display, int screen)
+static XVisualInfo *X11_GL_GetTransparentVisualInfo(Display *display, int screen)
 {
-    XVisualInfo* visualinfo = NULL;
+    XVisualInfo *visualinfo = NULL;
     XVisualInfo vi_in;
     int out_count = 0;
 
@@ -623,7 +630,7 @@ static XVisualInfo* X11_GL_GetTransparentVisualInfo(Display *display, int screen
     if (visualinfo != NULL) {
         int i = 0;
         for (i = 0; i < out_count; i++) {
-            XVisualInfo* v = &visualinfo[i];
+            XVisualInfo *v = &visualinfo[i];
             Uint32 format = X11_GetPixelFormatFromVisualInfo(display, v);
             if (SDL_ISPIXELFORMAT_ALPHA(format)) {
                 vi_in.screen = screen;
@@ -699,7 +706,7 @@ XVisualInfo *X11_GL_GetVisual(SDL_VideoDevice *_this, Display *display, int scre
         Uint32 format = X11_GetPixelFormatFromVisualInfo(display, vinfo);
         if (!SDL_ISPIXELFORMAT_ALPHA(format)) {
             // not transparent!
-            XVisualInfo* visualinfo = X11_GL_GetTransparentVisualInfo(display, screen);
+            XVisualInfo *visualinfo = X11_GL_GetTransparentVisualInfo(display, screen);
             if (visualinfo != NULL) {
                 X11_XFree(vinfo);
                 vinfo = visualinfo;
@@ -858,7 +865,7 @@ SDL_GLContext X11_GL_CreateContext(SDL_VideoDevice *_this, SDL_Window *window)
                     if (transparent && (framebuffer_config != NULL)) {
                         int i;
                         for (i = 0; i < fbcount; i++) {
-                            XVisualInfo* vinfo_temp = _this->gl_data->glXGetVisualFromFBConfig(display, framebuffer_config[i]);
+                            XVisualInfo *vinfo_temp = _this->gl_data->glXGetVisualFromFBConfig(display, framebuffer_config[i]);
                             if ( vinfo_temp != NULL) {
                                 Uint32 format = X11_GetPixelFormatFromVisualInfo(display, vinfo_temp);
                                 if (SDL_ISPIXELFORMAT_ALPHA(format)) {
